yt.data\_objects.index\_subobjects.octree\_subset module
========================================================

.. automodule:: yt.data_objects.index_subobjects.octree_subset
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
